# Now What?

Now that you've gone through the Getting Started section, you'll probably ask: "Now what?"

We want to provide a few different avenues and suggested paths forward based on your use cases and background.
These are not the only ways to use Aviary and explicitly do not build on each other.
You could start with one of these sections and then move to another, or you could start with one and never use the others.

## Starting Simple

If you just want to start from an existing example and run it, you can do that!
Look at the [Examples docs section](../examples/intro.md), start with a simple one, and modify it as you please.

We generally recommend starting by running cases using only the `"simple"` mission.
This mission is designed to be more robust and easier to run than other mission types.
[This doc page](../user_guide/drawing_and_running_simple_missions) goes into more detail about how to draw and run simple missions.

## Adding an External Subsystem

If you're a user who knows you want to add your own external subsystems and want to get right into it, check out the [external subsystems doc pages](../user_guide/subsystems).
Maybe you want to take an existing aircraft and mission and do some trade studies on the effects of adding a new propulsion system, structural model, or other external subsystem.
If you're not designing an aircraft from the ground up, you might be able to effectively use Aviary without going too deep in the docs or details.

## Doing Optimization Studies

The idea of doing "optimization" using Aviary is quite multifaceted.

You might want to keep an aircraft design fixed and optimize different mission profiles to see how an aircraft should optimally fly for a given range.
Or you might want to redesign an aircraft by doing a wingspan trade study and flying a fixed mission.
Or you can have a fully coupled optimization problem where you're optimizing the aircraft design and mission profile simultaneously.

For all these problems and more, Aviary can help you better explore your aircraft design space.

## Go on and Design

These are just examples of how you might use Aviary -- the sky is the limit! (For now...)
